.. _installation-ref:

Installation
============

The package can be installed using ``pip``.

.. code-block:: bash

    pip install openclean-notebook


You can use the additional `[jupyter]` option to install the Python Jupyter package if you want to use the UI within a Jupyter Notebook.

.. code-block:: bash

    pip install openclean-notebook[jupyter]


The notebook UI is a JavaScript bundle that is included in the installed package.
